summaryrefslogtreecommitdiffstats
path: root/filters/karbon
diff options
context:
space:
mode:
Diffstat (limited to 'filters/karbon')
-rw-r--r--filters/karbon/ai/aielement.cc2
-rw-r--r--filters/karbon/ai/aiimport.cc2
-rw-r--r--filters/karbon/ai/aiimport.h2
-rw-r--r--filters/karbon/applixgraphics/applixgraphicimport.cc10
-rw-r--r--filters/karbon/applixgraphics/applixgraphicimport.h2
-rw-r--r--filters/karbon/eps/epsexport.cc6
-rw-r--r--filters/karbon/eps/epsexport.h2
-rw-r--r--filters/karbon/eps/epsimport.cc4
-rw-r--r--filters/karbon/eps/epsimport.h2
-rw-r--r--filters/karbon/kontour/kontourimport.cpp6
-rw-r--r--filters/karbon/kontour/kontourimport.h2
-rw-r--r--filters/karbon/msod/msod.cc78
-rw-r--r--filters/karbon/msod/msod.h12
-rw-r--r--filters/karbon/msod/msodimport.cc18
-rw-r--r--filters/karbon/msod/msodimport.h4
-rw-r--r--filters/karbon/oodraw/oodrawimport.cc14
-rw-r--r--filters/karbon/oodraw/oodrawimport.h6
-rw-r--r--filters/karbon/png/pngexport.cc2
-rw-r--r--filters/karbon/png/pngexport.h2
-rw-r--r--filters/karbon/svg/svgexport.cc8
-rw-r--r--filters/karbon/svg/svgexport.h2
-rw-r--r--filters/karbon/svg/svgimport.cc20
-rw-r--r--filters/karbon/svg/svgimport.h2
-rw-r--r--filters/karbon/wmf/wmfexport.cc2
-rw-r--r--filters/karbon/wmf/wmfexport.h4
-rw-r--r--filters/karbon/wmf/wmfimport.cc2
-rw-r--r--filters/karbon/wmf/wmfimport.h2
-rw-r--r--filters/karbon/xaml/xamlexport.cc4
-rw-r--r--filters/karbon/xaml/xamlexport.h2
-rw-r--r--filters/karbon/xaml/xamlimport.cc20
-rw-r--r--filters/karbon/xaml/xamlimport.h2
-rw-r--r--filters/karbon/xcf/xcfexport.cc60
-rw-r--r--filters/karbon/xcf/xcfexport.h2
-rw-r--r--filters/karbon/xfig/xfigimport.cc12
34 files changed, 160 insertions, 160 deletions
diff --git a/filters/karbon/ai/aielement.cc b/filters/karbon/ai/aielement.cc
index 023943b9..608bdf61 100644
--- a/filters/karbon/ai/aielement.cc
+++ b/filters/karbon/ai/aielement.cc
@@ -360,7 +360,7 @@ AIElement::Type AIElement::nameToType( const char* name )
const TQString AIElement::toString() const
{
if ( d->typ == CString )
- return TQString::fromLatin1( toCString() );
+ return TQString::tqfromLatin1( toCString() );
if ( d->typ == Int )
return TQString::number( toInt() );
if ( d->typ == UInt )
diff --git a/filters/karbon/ai/aiimport.cc b/filters/karbon/ai/aiimport.cc
index 4e854995..4a201ec5 100644
--- a/filters/karbon/ai/aiimport.cc
+++ b/filters/karbon/ai/aiimport.cc
@@ -56,7 +56,7 @@ AiImport::~AiImport()
{
}
-KoFilter::ConversionStatus
+KoFilter::ConversiontqStatus
AiImport::convert( const TQCString& from, const TQCString& to )
{
if ( from != "application/illustrator" || to != "application/x-karbon" )
diff --git a/filters/karbon/ai/aiimport.h b/filters/karbon/ai/aiimport.h
index 3dd9a560..c305b536 100644
--- a/filters/karbon/ai/aiimport.h
+++ b/filters/karbon/ai/aiimport.h
@@ -36,7 +36,7 @@ public:
AiImport( KoFilter* parent, const char* name, const TQStringList& );
virtual ~AiImport();
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
/* private:
TQString m_result; */
diff --git a/filters/karbon/applixgraphics/applixgraphicimport.cc b/filters/karbon/applixgraphics/applixgraphicimport.cc
index 47c5f2b6..b3df1581 100644
--- a/filters/karbon/applixgraphics/applixgraphicimport.cc
+++ b/filters/karbon/applixgraphics/applixgraphicimport.cc
@@ -26,7 +26,7 @@
#include <kdebug.h>
#include <tqfile.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqmessagebox.h>
#include <KoFilterChain.h>
#include <kgenericfactory.h>
@@ -133,7 +133,7 @@ APPLIXGRAPHICImport::APPLIXGRAPHICImport (KoFilter *, const char *, const TQStri
* *
* *
******************************************************************************/
-KoFilter::ConversionStatus APPLIXGRAPHICImport::convert( const TQCString& from, const TQCString& to )
+KoFilter::ConversiontqStatus APPLIXGRAPHICImport::convert( const TQCString& from, const TQCString& to )
{
// Check MIME Types
@@ -156,7 +156,7 @@ KoFilter::ConversionStatus APPLIXGRAPHICImport::convert( const TQCString& from,
str += "<!DOCTYPE karbon>\n";
str += " <karbon mime=\"application/x-karbon\" version=\"2\" editor=\"APPLIXGRAPHICS import filter\">\n";
// str += " <head>\n";
-// str += " <layout width=\"210\" lmargin=\"0\" format=\"a4\" bmargin=\"0\" height=\"297\" rmargin=\"0\" tmargin=\"0\" orientation=\"portrait\"/>\n";
+// str += " <tqlayout width=\"210\" lmargin=\"0\" format=\"a4\" bmargin=\"0\" height=\"297\" rmargin=\"0\" tmargin=\"0\" orientation=\"portrait\"/>\n";
// str += " <grid dx=\"20\" dy=\"20\" align=\"0\">\n";
// str += " <helplines align=\"0\"/>\n";
// str += " </grid>\n";
@@ -189,10 +189,10 @@ KoFilter::ConversionStatus APPLIXGRAPHICImport::convert( const TQCString& from,
TQMessageBox::critical (0L, "Applixgraphics header problem",
TQString ("The Applixgraphics header is not correct. "
"May be it is not an applixgraphics file! <BR>"
- "This is the header line I did read:<BR><B>%1</B>").arg(mystr.latin1()),
+ "This is the header line I did read:<BR><B>%1</B>").tqarg(mystr.latin1()),
"Comma");
- // i18n( "What is the separator used in this file ? First line is \n%1" ).arg(firstLine),
+ // i18n( "What is the separator used in this file ? First line is \n%1" ).tqarg(firstLine),
return KoFilter::StupidError;
}
diff --git a/filters/karbon/applixgraphics/applixgraphicimport.h b/filters/karbon/applixgraphics/applixgraphicimport.h
index e0eff76c..3e42256e 100644
--- a/filters/karbon/applixgraphics/applixgraphicimport.h
+++ b/filters/karbon/applixgraphics/applixgraphicimport.h
@@ -32,7 +32,7 @@ public:
APPLIXGRAPHICImport (KoFilter *parent, const char *name, const TQStringList&);
virtual ~APPLIXGRAPHICImport() {}
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
};
diff --git a/filters/karbon/eps/epsexport.cc b/filters/karbon/eps/epsexport.cc
index 8696e6a3..e1bd06a5 100644
--- a/filters/karbon/eps/epsexport.cc
+++ b/filters/karbon/eps/epsexport.cc
@@ -87,7 +87,7 @@ EpsExport::EpsExport( KoFilter*, const char*, const TQStringList& )
{
}
-KoFilter::ConversionStatus
+KoFilter::ConversiontqStatus
EpsExport::convert( const TQCString& from, const TQCString& to )
{
if ( to != "image/x-eps" || from != "application/x-karbon" )
@@ -102,7 +102,7 @@ EpsExport::convert( const TQCString& from, const TQCString& to )
return KoFilter::StupidError;
- KoFilter::ConversionStatus status = KoFilter::OK;
+ KoFilter::ConversiontqStatus status = KoFilter::OK;
// Ask questions about PS level etc.
EpsExportDlg* dialog = new EpsExportDlg();
@@ -194,7 +194,7 @@ EpsExport::visitVDocument( VDocument& document )
static_cast<KoDocumentInfoAuthor*>( docInfo.page( "author" ) );
// Get creation date/time = "now".
- TQDateTime now( TQDateTime::currentDateTime() );
+ TQDateTime now( TQDateTime::tqcurrentDateTime() );
*m_stream <<
"%%CreationDate: (" << now.toString( Qt::LocalDate ) << ")\n"
diff --git a/filters/karbon/eps/epsexport.h b/filters/karbon/eps/epsexport.h
index f5867b43..1313294e 100644
--- a/filters/karbon/eps/epsexport.h
+++ b/filters/karbon/eps/epsexport.h
@@ -46,7 +46,7 @@ public:
EpsExport( KoFilter* parent, const char* name, const TQStringList& );
virtual ~EpsExport() {}
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
private:
virtual void visitVPath( VPath& composite );
diff --git a/filters/karbon/eps/epsimport.cc b/filters/karbon/eps/epsimport.cc
index 77a650bb..0fefb3e0 100644
--- a/filters/karbon/eps/epsimport.cc
+++ b/filters/karbon/eps/epsimport.cc
@@ -57,7 +57,7 @@ EpsImport::~EpsImport()
{
}
-KoFilter::ConversionStatus
+KoFilter::ConversiontqStatus
EpsImport::convert( const TQCString& from, const TQCString& to )
{
if(
@@ -93,7 +93,7 @@ EpsImport::convert( const TQCString& from, const TQCString& to )
// sed filter
TQString sedFilter = TQString ("sed -e \"s/%%BoundingBox: 0 0 612 792/%%BoundingBox: %1 %2 %3 %4/g\"").
- arg(llx).arg(lly).arg(urx).arg(ury);
+ tqarg(llx).tqarg(lly).tqarg(urx).tqarg(ury);
// Build ghostscript call to convert ps/eps -> ai:
TQString command(
diff --git a/filters/karbon/eps/epsimport.h b/filters/karbon/eps/epsimport.h
index c86be29d..873dc169 100644
--- a/filters/karbon/eps/epsimport.h
+++ b/filters/karbon/eps/epsimport.h
@@ -36,7 +36,7 @@ public:
EpsImport( KoFilter* parent, const char* name, const TQStringList& );
virtual ~EpsImport();
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
};
#endif
diff --git a/filters/karbon/kontour/kontourimport.cpp b/filters/karbon/kontour/kontourimport.cpp
index 30b77ccf..a260fd50 100644
--- a/filters/karbon/kontour/kontourimport.cpp
+++ b/filters/karbon/kontour/kontourimport.cpp
@@ -49,7 +49,7 @@ KontourImport::~KontourImport()
}
-KoFilter::ConversionStatus KontourImport::convert(const TQCString& from, const TQCString& to)
+KoFilter::ConversiontqStatus KontourImport::convert(const TQCString& from, const TQCString& to)
{
// check for proper conversion
if ( to != "application/x-karbon" || ( from != "application/x-kontour" && from != "application/x-killustrator") )
@@ -198,8 +198,8 @@ KontourImport::convert()
if( docElem.attribute( "version" ).toInt() == 2 )
{
lay = docElem;
- height = lay.firstChild().namedItem( "layout" ).toElement().attribute( "height" ).toDouble();
- width = lay.firstChild().namedItem( "layout" ).toElement().attribute( "width" ).toDouble();
+ height = lay.firstChild().namedItem( "tqlayout" ).toElement().attribute( "height" ).toDouble();
+ width = lay.firstChild().namedItem( "tqlayout" ).toElement().attribute( "width" ).toDouble();
}
else
{
diff --git a/filters/karbon/kontour/kontourimport.h b/filters/karbon/kontour/kontourimport.h
index 92e27a09..e140f088 100644
--- a/filters/karbon/kontour/kontourimport.h
+++ b/filters/karbon/kontour/kontourimport.h
@@ -33,7 +33,7 @@ public:
KontourImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~KontourImport();
- virtual KoFilter::ConversionStatus convert(const TQCString& from, const TQCString& to);
+ virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
protected:
TQDomDocument inpdoc;
diff --git a/filters/karbon/msod/msodimport.h b/filters/karbon/msod/msodimport.h
index 9264b7d5..162176de 100644
--- a/filters/karbon/msod/msodimport.h
+++ b/filters/karbon/msod/msodimport.h
@@ -39,7 +39,7 @@ public:
const TQStringList&);
virtual ~MSODImport();
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
protected:
@@ -68,7 +68,7 @@ protected:
signals:
// Communication signals to the parent filters
void commSignalDelayStream( const char* delay );
- void commSignalShapeID( unsigned int& shapeID );
+ void commSignalShapeID( unsigned int& tqshapeID );
private:
virtual void savePartContents( TQIODevice* file );
diff --git a/filters/karbon/oodraw/oodrawimport.cc b/filters/karbon/oodraw/oodrawimport.cc
index fba48867..90320d7e 100644
--- a/filters/karbon/oodraw/oodrawimport.cc
+++ b/filters/karbon/oodraw/oodrawimport.cc
@@ -62,7 +62,7 @@ OoDrawImport::~OoDrawImport()
{
}
-KoFilter::ConversionStatus OoDrawImport::convert( TQCString const & from, TQCString const & to )
+KoFilter::ConversiontqStatus OoDrawImport::convert( TQCString const & from, TQCString const & to )
{
kdDebug() << "Entering Oodraw Import filter: " << from << " - " << to << endl;
@@ -81,13 +81,13 @@ KoFilter::ConversionStatus OoDrawImport::convert( TQCString const & from, TQCStr
return KoFilter::FileNotFound;
}
- KoFilter::ConversionStatus preStatus = openFile();
+ KoFilter::ConversiontqStatus pretqStatus = openFile();
- if( preStatus != KoFilter::OK )
+ if( pretqStatus != KoFilter::OK )
{
m_zip->close();
delete m_zip;
- return preStatus;
+ return pretqStatus;
}
/*TQDomDocument docinfo;
createDocumentInfo( docinfo );
@@ -149,9 +149,9 @@ void OoDrawImport::createDocumentInfo( TQDomDocument &docinfo )
// Very related to OoWriterImport::openFile()
-KoFilter::ConversionStatus OoDrawImport::openFile()
+KoFilter::ConversiontqStatus OoDrawImport::openFile()
{
- KoFilter::ConversionStatus status = loadAndParse( "content.xml", m_content );
+ KoFilter::ConversiontqStatus status = loadAndParse( "content.xml", m_content );
if ( status != KoFilter::OK )
{
kdError(30518) << "Content.xml could not be parsed correctly! Aborting!" << endl;
@@ -223,7 +223,7 @@ void OoDrawImport::convert()
}
-KoFilter::ConversionStatus OoDrawImport::loadAndParse(const TQString& filename, TQDomDocument& doc)
+KoFilter::ConversiontqStatus OoDrawImport::loadAndParse(const TQString& filename, TQDomDocument& doc)
{
return OoUtils::loadAndParse( filename, doc, m_zip);
}
diff --git a/filters/karbon/oodraw/oodrawimport.h b/filters/karbon/oodraw/oodrawimport.h
index 6e753d7d..2b395f48 100644
--- a/filters/karbon/oodraw/oodrawimport.h
+++ b/filters/karbon/oodraw/oodrawimport.h
@@ -43,7 +43,7 @@ public:
OoDrawImport( KoFilter *parent, const char *name, const TQStringList & );
virtual ~OoDrawImport();
- virtual KoFilter::ConversionStatus convert( TQCString const & from, TQCString const & to );
+ virtual KoFilter::ConversiontqStatus convert( TQCString const & from, TQCString const & to );
private:
void createDocumentInfo( TQDomDocument &docinfo );
@@ -63,8 +63,8 @@ private:
double ymirror( double y );
KoRect parseViewBox( const TQDomElement& object );
- KoFilter::ConversionStatus openFile();
- KoFilter::ConversionStatus loadAndParse(const TQString& filename, TQDomDocument& doc);
+ KoFilter::ConversiontqStatus openFile();
+ KoFilter::ConversiontqStatus loadAndParse(const TQString& filename, TQDomDocument& doc);
VDocument m_document;
TQDomDocument m_content;
diff --git a/filters/karbon/png/pngexport.cc b/filters/karbon/png/pngexport.cc
index 89b43d03..4de61a44 100644
--- a/filters/karbon/png/pngexport.cc
+++ b/filters/karbon/png/pngexport.cc
@@ -48,7 +48,7 @@ PngExport::PngExport( KoFilter*, const char*, const TQStringList& )
{
}
-KoFilter::ConversionStatus
+KoFilter::ConversiontqStatus
PngExport::convert( const TQCString& from, const TQCString& to )
{
if ( to != "image/png" || from != "application/x-karbon" )
diff --git a/filters/karbon/png/pngexport.h b/filters/karbon/png/pngexport.h
index df893965..3758daa3 100644
--- a/filters/karbon/png/pngexport.h
+++ b/filters/karbon/png/pngexport.h
@@ -33,7 +33,7 @@ public:
PngExport( KoFilter* parent, const char* name, const TQStringList& );
virtual ~PngExport() {}
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
};
#endif
diff --git a/filters/karbon/svg/svgexport.cc b/filters/karbon/svg/svgexport.cc
index a5ed9b40..2e661039 100644
--- a/filters/karbon/svg/svgexport.cc
+++ b/filters/karbon/svg/svgexport.cc
@@ -67,7 +67,7 @@ SvgExport::SvgExport( KoFilter*, const char*, const TQStringList& )
m_gc.setAutoDelete( true );
}
-KoFilter::ConversionStatus
+KoFilter::ConversiontqStatus
SvgExport::convert( const TQCString& from, const TQCString& to )
{
if ( to != "image/svg+xml" || from != "application/x-karbon" )
@@ -171,7 +171,7 @@ TQString
SvgExport::getID( VObject *obj )
{
if( obj && !obj->name().isEmpty() )
- return TQString( " id=\"%1\"" ).arg( obj->name() );
+ return TQString( " id=\"%1\"" ).tqarg( obj->name() );
return TQString();
}
@@ -490,9 +490,9 @@ SvgExport::visitVText( VText& text )
*m_body << " font-weight=\"bold\"";
if( text.font().italic() )
*m_body << " font-style=\"italic\"";
- if( text.alignment() == VText::Center )
+ if( text.tqalignment() == VText::Center )
*m_body << " text-anchor=\"middle\"";
- else if( text.alignment() == VText::Right )
+ else if( text.tqalignment() == VText::Right )
*m_body << " text-anchor=\"end\"";
*m_body << ">" << endl;
diff --git a/filters/karbon/svg/svgexport.h b/filters/karbon/svg/svgexport.h
index c79d1fde..6bfe5d98 100644
--- a/filters/karbon/svg/svgexport.h
+++ b/filters/karbon/svg/svgexport.h
@@ -52,7 +52,7 @@ public:
SvgExport( KoFilter* parent, const char* name, const TQStringList& );
virtual ~SvgExport() {}
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
private:
virtual void visitVPath( VPath& composite );
diff --git a/filters/karbon/svg/svgimport.cc b/filters/karbon/svg/svgimport.cc
index 9d323d3d..5a5e90aa 100644
--- a/filters/karbon/svg/svgimport.cc
+++ b/filters/karbon/svg/svgimport.cc
@@ -54,7 +54,7 @@ SvgImport::~SvgImport()
{
}
-KoFilter::ConversionStatus SvgImport::convert(const TQCString& from, const TQCString& to)
+KoFilter::ConversiontqStatus SvgImport::convert(const TQCString& from, const TQCString& to)
{
// check for proper conversion
if( to != "application/x-karbon" || from != "image/svg+xml" )
@@ -138,7 +138,7 @@ void SvgImport::convert()
m_outerRect = m_document.boundingBox();
// undo y-mirroring
- //m_debug->append(TQString("%1\tUndo Y-mirroring.").arg(m_time.elapsed()));
+ //m_debug->append(TQString("%1\tUndo Y-mirroring.").tqarg(m_time.elapsed()));
if( !docElem.attribute( "viewBox" ).isEmpty() )
{
// allow for viewbox def with ',' or whitespace
@@ -692,17 +692,17 @@ void SvgImport::parsePA( VObject *obj, SvgGraphicsContext *gc, const TQString &c
//kdDebug() << "!!!!!!bbox y : " << bbox.y() << endl;
//kdDebug() << gc->fill.gradient().origin().x() << endl;
//kdDebug() << gc->fill.gradient().vector().x() << endl;
- double offsetx = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().origin().x() ), true, false, bbox );
- double offsety = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().origin().y() ), false, true, bbox );
+ double offsetx = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().origin().x() ), true, false, bbox );
+ double offsety = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().origin().y() ), false, true, bbox );
gc->fill.gradient().setOrigin( KoPoint( bbox.x() + offsetx, bbox.y() + offsety ) );
if(gc->fill.gradient().type() == VGradient::radial)
{
- offsetx = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().focalPoint().x() ), true, false, bbox );
- offsety = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().focalPoint().y() ), false, true, bbox );
+ offsetx = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().focalPoint().x() ), true, false, bbox );
+ offsety = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().focalPoint().y() ), false, true, bbox );
gc->fill.gradient().setFocalPoint( KoPoint( bbox.x() + offsetx, bbox.y() + offsety ) );
}
- offsetx = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().vector().x() ), true, false, bbox );
- offsety = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().vector().y() ), false, true, bbox );
+ offsetx = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().vector().x() ), true, false, bbox );
+ offsety = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().vector().y() ), false, true, bbox );
gc->fill.gradient().setVector( KoPoint( bbox.x() + offsetx, bbox.y() + offsety ) );
//kdDebug() << offsety << endl;
//kdDebug() << gc->fill.gradient().origin().x() << endl;
@@ -1263,9 +1263,9 @@ void SvgImport::createText( VGroup *grp, const TQDomElement &b )
text->setName( b.attribute("id") );
if( anchor == "middle" )
- text->setAlignment( VText::Center );
+ text->tqsetAlignment( VText::Center );
else if( anchor == "end" )
- text->setAlignment( VText::Right );
+ text->tqsetAlignment( VText::Right );
if( offset > 0.0 )
text->setOffset( offset );
diff --git a/filters/karbon/svg/svgimport.h b/filters/karbon/svg/svgimport.h
index 636077a1..e4e3f56a 100644
--- a/filters/karbon/svg/svgimport.h
+++ b/filters/karbon/svg/svgimport.h
@@ -45,7 +45,7 @@ public:
SvgImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~SvgImport();
- virtual KoFilter::ConversionStatus convert(const TQCString& from, const TQCString& to);
+ virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
protected:
class GradientHelper
diff --git a/filters/karbon/wmf/wmfexport.cc b/filters/karbon/wmf/wmfexport.cc
index de929ca8..a04dfc11 100644
--- a/filters/karbon/wmf/wmfexport.cc
+++ b/filters/karbon/wmf/wmfexport.cc
@@ -57,7 +57,7 @@ WmfExport::~WmfExport()
{
}
-KoFilter::ConversionStatus WmfExport::convert( const TQCString& from, const TQCString& to )
+KoFilter::ConversiontqStatus WmfExport::convert( const TQCString& from, const TQCString& to )
{
if( to != "image/x-wmf" || from != "application/x-karbon" ) {
return KoFilter::NotImplemented;
diff --git a/filters/karbon/wmf/wmfexport.h b/filters/karbon/wmf/wmfexport.h
index 2c464f13..e0c9be57 100644
--- a/filters/karbon/wmf/wmfexport.h
+++ b/filters/karbon/wmf/wmfexport.h
@@ -20,7 +20,7 @@
#define WMFEXPORT_H
#include <tqpen.h>
-#include <brush.h>
+#include <tqbrush.h>
#include <tqptrlist.h>
#include <tqpointarray.h>
#include <KoFilter.h>
@@ -41,7 +41,7 @@ public:
WmfExport( KoFilter *parent, const char *name, const TQStringList&);
virtual ~WmfExport();
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
private:
void visitVPath( VPath& composite );
diff --git a/filters/karbon/wmf/wmfimport.cc b/filters/karbon/wmf/wmfimport.cc
index f7dcdcf3..23eaaa12 100644
--- a/filters/karbon/wmf/wmfimport.cc
+++ b/filters/karbon/wmf/wmfimport.cc
@@ -45,7 +45,7 @@ WMFImport::~WMFImport()
{
}
-KoFilter::ConversionStatus WMFImport::convert( const TQCString& from, const TQCString& to )
+KoFilter::ConversiontqStatus WMFImport::convert( const TQCString& from, const TQCString& to )
{
if( to != "application/x-karbon" || from != "image/x-wmf" )
return KoFilter::NotImplemented;
diff --git a/filters/karbon/wmf/wmfimport.h b/filters/karbon/wmf/wmfimport.h
index 34ee8140..21bcee74 100644
--- a/filters/karbon/wmf/wmfimport.h
+++ b/filters/karbon/wmf/wmfimport.h
@@ -36,7 +36,7 @@ public:
WMFImport( KoFilter *parent, const char *name, const TQStringList&);
virtual ~WMFImport();
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
};
diff --git a/filters/karbon/xaml/xamlexport.cc b/filters/karbon/xaml/xamlexport.cc
index e1599a8c..228024f3 100644
--- a/filters/karbon/xaml/xamlexport.cc
+++ b/filters/karbon/xaml/xamlexport.cc
@@ -60,7 +60,7 @@ XAMLExport::XAMLExport( KoFilter*, const char*, const TQStringList& )
m_gc.setAutoDelete( true );
}
-KoFilter::ConversionStatus
+KoFilter::ConversiontqStatus
XAMLExport::convert( const TQCString& from, const TQCString& to )
{
// TODO: ???
@@ -161,7 +161,7 @@ TQString
XAMLExport::getID( VObject *obj )
{
if( obj && !obj->name().isEmpty() )
- return TQString( " Name=\"%1\"" ).arg( obj->name() );
+ return TQString( " Name=\"%1\"" ).tqarg( obj->name() );
return TQString();
}
diff --git a/filters/karbon/xaml/xamlexport.h b/filters/karbon/xaml/xamlexport.h
index 124ea3fd..b1a0f4fd 100644
--- a/filters/karbon/xaml/xamlexport.h
+++ b/filters/karbon/xaml/xamlexport.h
@@ -50,7 +50,7 @@ public:
XAMLExport( KoFilter* parent, const char* name, const TQStringList& );
virtual ~XAMLExport() {}
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
private:
virtual void visitVPath( VPath& composite );
diff --git a/filters/karbon/xaml/xamlimport.cc b/filters/karbon/xaml/xamlimport.cc
index 002001e2..3a755181 100644
--- a/filters/karbon/xaml/xamlimport.cc
+++ b/filters/karbon/xaml/xamlimport.cc
@@ -24,9 +24,9 @@
#include <kdebug.h>
#include <KoUnit.h>
#include <KoGlobal.h>
-#include <shapes/vellipse.h>
-#include <shapes/vrectangle.h>
-#include <shapes/vpolygon.h>
+#include <tqshapes/vellipse.h>
+#include <tqshapes/vrectangle.h>
+#include <tqshapes/vpolygon.h>
#include <commands/vtransformcmd.h>
#include <core/vsegment.h>
#include <core/vtext.h>
@@ -52,7 +52,7 @@ XAMLImport::~XAMLImport()
{
}
-KoFilter::ConversionStatus XAMLImport::convert(const TQCString& from, const TQCString& to)
+KoFilter::ConversiontqStatus XAMLImport::convert(const TQCString& from, const TQCString& to)
{
// check for proper conversion
if( to != "application/x-karbon" || from != "image/wvg+xml" )
@@ -466,14 +466,14 @@ XAMLImport::parsePA( VObject *obj, XAMLGraphicsContext *gc, const TQString &comm
//kdDebug() << "!!!!!!bbox y : " << bbox.y() << endl;
//kdDebug() << gc->fill.gradient().origin().x() << endl;
//kdDebug() << gc->fill.gradient().vector().x() << endl;
- double offsetx = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().origin().x() ), true, false, bbox );
- double offsety = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().origin().y() ), false, true, bbox );
+ double offsetx = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().origin().x() ), true, false, bbox );
+ double offsety = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().origin().y() ), false, true, bbox );
gc->fill.gradient().setOrigin( KoPoint( bbox.x() + offsetx, bbox.y() + offsety ) );
- offsetx = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().focalPoint().x() ), true, false, bbox );
- offsety = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().focalPoint().y() ), false, true, bbox );
+ offsetx = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().focalPoint().x() ), true, false, bbox );
+ offsety = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().focalPoint().y() ), false, true, bbox );
gc->fill.gradient().setFocalPoint( KoPoint( bbox.x() + offsetx, bbox.y() + offsety ) );
- offsetx = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().vector().x() ), true, false, bbox );
- offsety = parseUnit( TQString( "%1%" ).arg( gc->fill.gradient().vector().y() ), false, true, bbox );
+ offsetx = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().vector().x() ), true, false, bbox );
+ offsety = parseUnit( TQString( "%1%" ).tqarg( gc->fill.gradient().vector().y() ), false, true, bbox );
gc->fill.gradient().setVector( KoPoint( bbox.x() + offsetx, bbox.y() + offsety ) );
//kdDebug() << offsety << endl;
//kdDebug() << gc->fill.gradient().origin().x() << endl;
diff --git a/filters/karbon/xaml/xamlimport.h b/filters/karbon/xaml/xamlimport.h
index 001d1dc3..b61313b9 100644
--- a/filters/karbon/xaml/xamlimport.h
+++ b/filters/karbon/xaml/xamlimport.h
@@ -43,7 +43,7 @@ public:
XAMLImport(KoFilter *parent, const char *name, const TQStringList&);
virtual ~XAMLImport();
- virtual KoFilter::ConversionStatus convert(const TQCString& from, const TQCString& to);
+ virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
protected:
class GradientHelper
diff --git a/filters/karbon/xcf/xcfexport.cc b/filters/karbon/xcf/xcfexport.cc
index 215c4f01..3e9237fb 100644
--- a/filters/karbon/xcf/xcfexport.cc
+++ b/filters/karbon/xcf/xcfexport.cc
@@ -52,7 +52,7 @@ XcfExport::XcfExport( KoFilter*, const char*, const TQStringList& )
m_zoomY = 1.0;
}
-KoFilter::ConversionStatus
+KoFilter::ConversiontqStatus
XcfExport::convert( const TQCString& from, const TQCString& to )
{
if( to != "image/x-xcf-gimp" || from != "application/x-karbon" )
@@ -128,10 +128,10 @@ XcfExport::visitVDocument( VDocument& document )
// Save current offset.
- current = m_stream->device()->at();
+ current = m_stream->tqdevice()->at();
// Leave space for layer and channel offsets.
- m_stream->device()->at(
+ m_stream->tqdevice()->at(
// current position + (number layers + number channels + 2) * 4.
current + ( document.layers().count() + 3 + 2 ) * 4 );
@@ -142,7 +142,7 @@ XcfExport::visitVDocument( VDocument& document )
for( ; itr.current(); ++itr )
{
// Save start offset.
- start = m_stream->device()->at();
+ start = m_stream->tqdevice()->at();
// Write layer.
@@ -150,31 +150,31 @@ XcfExport::visitVDocument( VDocument& document )
// Save end offset.
- end = m_stream->device()->at();
+ end = m_stream->tqdevice()->at();
// Return to current offset.
- m_stream->device()->at( current );
+ m_stream->tqdevice()->at( current );
// Save layer offset.
*m_stream << start;
// Increment offset.
- current = m_stream->device()->at();
+ current = m_stream->tqdevice()->at();
// Return to end offset.
- m_stream->device()->at( end );
+ m_stream->tqdevice()->at( end );
}
// Return to current offset.
- m_stream->device()->at( current );
+ m_stream->tqdevice()->at( current );
// Append a zero offset to indicate end of layer offsets.
*m_stream << static_cast<TQ_UINT32>( 0 );
// Return to end offset.
- m_stream->device()->at( end );
+ m_stream->tqdevice()->at( end );
// Append a zero offset to indicate end of channel offsets.
*m_stream << static_cast<TQ_UINT32>( 0 );
@@ -279,13 +279,13 @@ XcfExport::visitVLayer( VLayer& layer )
TQIODevice::Offset end = 0;
// Save current offset.
- current = m_stream->device()->at();
+ current = m_stream->tqdevice()->at();
// Leave space for hierarchy offsets.
- m_stream->device()->at( current + 8 );
+ m_stream->tqdevice()->at( current + 8 );
// Save start offset.
- start = m_stream->device()->at();
+ start = m_stream->tqdevice()->at();
// Write hierarchy.
@@ -293,10 +293,10 @@ XcfExport::visitVLayer( VLayer& layer )
// Save end offset.
- end = m_stream->device()->at();
+ end = m_stream->tqdevice()->at();
// Return to current offset.
- m_stream->device()->at( current );
+ m_stream->tqdevice()->at( current );
// Save hierarchy offset.
*m_stream << start;
@@ -333,15 +333,15 @@ XcfExport::writeHierarchy()
int height = m_height;
// Save current offset.
- current = m_stream->device()->at();
+ current = m_stream->tqdevice()->at();
// Leave space for level offsets.
- m_stream->device()->at( current + ( levels + 1 ) * 4 );
+ m_stream->tqdevice()->at( current + ( levels + 1 ) * 4 );
for( int i = 0; i < levels; ++i )
{
// Save start offset.
- start = m_stream->device()->at();
+ start = m_stream->tqdevice()->at();
if( i == 0 )
{
@@ -360,23 +360,23 @@ XcfExport::writeHierarchy()
}
// Save end offset.
- end = m_stream->device()->at();
+ end = m_stream->tqdevice()->at();
// Return to current offset.
- m_stream->device()->at( current );
+ m_stream->tqdevice()->at( current );
// Save level offset.
*m_stream << start;
// Increment offset.
- current = m_stream->device()->at();
+ current = m_stream->tqdevice()->at();
// Return to end offset.
- m_stream->device()->at( end );
+ m_stream->tqdevice()->at( end );
}
// Return to current offset.
- m_stream->device()->at( current );
+ m_stream->tqdevice()->at( current );
// Append a zero offset to indicate end of level offsets.
*m_stream << static_cast<TQ_UINT32>( 0 );
@@ -398,15 +398,15 @@ XcfExport::writeLevel()
int tiles = rows * cols;
// Save current offset.
- current = m_stream->device()->at();
+ current = m_stream->tqdevice()->at();
// Leave space for tile offsets.
- m_stream->device()->at( current + ( tiles + 1 ) * 4 );
+ m_stream->tqdevice()->at( current + ( tiles + 1 ) * 4 );
for( int i = 0; i < tiles; ++i )
{
// Save start offset.
- start = m_stream->device()->at();
+ start = m_stream->tqdevice()->at();
// TODO: Save tile.
@@ -425,19 +425,19 @@ XcfExport::writeLevel()
// Save end offset.
- end = m_stream->device()->at();
+ end = m_stream->tqdevice()->at();
// Return to current offset.
- m_stream->device()->at( current );
+ m_stream->tqdevice()->at( current );
// Save tile offset.
*m_stream << start;
// Increment offset.
- current = m_stream->device()->at();
+ current = m_stream->tqdevice()->at();
// Return to end offset.
- m_stream->device()->at( end );
+ m_stream->tqdevice()->at( end );
}
}
diff --git a/filters/karbon/xcf/xcfexport.h b/filters/karbon/xcf/xcfexport.h
index f6a7be70..82d86883 100644
--- a/filters/karbon/xcf/xcfexport.h
+++ b/filters/karbon/xcf/xcfexport.h
@@ -40,7 +40,7 @@ public:
XcfExport( KoFilter* parent, const char* name, const TQStringList& );
virtual ~XcfExport() {}
- virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
virtual void visitVDocument( VDocument& document );
virtual void visitVLayer( VLayer& layer );
diff --git a/filters/karbon/xfig/xfigimport.cc b/filters/karbon/xfig/xfigimport.cc
index c3d6ab6a..015c4006 100644
--- a/filters/karbon/xfig/xfigimport.cc
+++ b/filters/karbon/xfig/xfigimport.cc
@@ -167,7 +167,7 @@ bool XFIGImport::filterImport( const TQString &file, KoDocument *doc,
char buf[255];
int value;
- KoPageLayout layout;
+ KoPageLayout tqlayout;
ifstream fin( file.local8Bit() );
if (! fin)
@@ -177,7 +177,7 @@ bool XFIGImport::filterImport( const TQString &file, KoDocument *doc,
GDocument *gdoc = kidoc->gdoc();
//GPage *activePage = gdoc->activePage();
- layout = gdoc->activePage()->pageLayout ();
+ tqlayout = gdoc->activePage()->pageLayout ();
fin.getline (buf, 255);
if (::strncmp (buf, "#FIG 3", 6)) {
@@ -203,9 +203,9 @@ bool XFIGImport::filterImport( const TQString &file, KoDocument *doc,
// orientation
fin.getline (buf, 255);
if (::strcmp (buf, "Landscape") == 0)
- layout.orientation = PG_LANDSCAPE;
+ tqlayout.orientation = PG_LANDSCAPE;
else if (::strcmp (buf, "Portrait") == 0)
- layout.orientation = PG_PORTRAIT;
+ tqlayout.orientation = PG_PORTRAIT;
else
kdDebug() << "ERROR: invalid orientation" << endl;
@@ -215,9 +215,9 @@ bool XFIGImport::filterImport( const TQString &file, KoDocument *doc,
// units
fin.getline (buf, 255);
if (::strcmp (buf, "Metric") == 0)
- layout.unit = PG_MM;
+ tqlayout.unit = PG_MM;
else if (::strcmp (buf, "Inches") == 0)
- layout.unit = PG_INCH;
+ tqlayout.unit = PG_INCH;
else
kdDebug() << "ERROR: invalid units" << endl;
diff --git a/filters/karbon/msod/msod.cc b/filters/karbon/msod/msod.cc
index 8c4c2795..3e79e3ab 100644
--- a/filters/karbon/msod/msod.cc
+++ b/filters/karbon/msod/msod.cc
@@ -39,18 +39,18 @@ Msod::Msod(
m_dpi = dpi;
m_images.setAutoDelete(true);
m_opt = new Options(*this);
- m_shape.data = 0L;
- m_shape.length = 0;
+ m_tqshape.data = 0L;
+ m_tqshape.length = 0;
}
Msod::~Msod()
{
- delete [] m_shape.data;
+ delete [] m_tqshape.data;
delete m_opt;
}
void Msod::drawShape(
- unsigned shapeType,
+ unsigned tqshapeType,
TQ_UINT32 bytes,
TQDataStream &operands)
{
@@ -262,25 +262,25 @@ void Msod::drawShape(
};
struct
{
- TQ_UINT32 spid; // The shape id
+ TQ_UINT32 spid; // The tqshape id
union
{
TQ_UINT32 info;
struct
{
- TQ_UINT32 fGroup : 1; // This shape is a group shape
- TQ_UINT32 fChild : 1; // Not a top-level shape
- TQ_UINT32 fPatriarch : 1; // This is the topmost group shape.
+ TQ_UINT32 fGroup : 1; // This tqshape is a group tqshape
+ TQ_UINT32 fChild : 1; // Not a top-level tqshape
+ TQ_UINT32 fPatriarch : 1; // This is the topmost group tqshape.
// Exactly one of these per drawing.
TQ_UINT32 fDeleted : 1; // The shape.has been deleted
- TQ_UINT32 fOleShape : 1; // The shape is an OLE object
+ TQ_UINT32 fOleShape : 1; // The tqshape is an OLE object
TQ_UINT32 fHaveMaster : 1; // Shape has a hspMaster property
TQ_UINT32 fFlipH : 1; // Shape is flipped horizontally
TQ_UINT32 fFlipV : 1; // Shape is flipped vertically
- TQ_UINT32 fConnector : 1; // Connector type of shape
+ TQ_UINT32 fConnector : 1; // Connector type of tqshape
TQ_UINT32 fHaveAnchor : 1; // Shape has an anchor of some kind
- TQ_UINT32 fBackground : 1; // Background shape
- TQ_UINT32 fHaveSpt : 1; // Shape has a shape type property
+ TQ_UINT32 fBackground : 1; // Background tqshape
+ TQ_UINT32 fHaveSpt : 1; // Shape has a tqshape type property
TQ_UINT32 reserved : 20; // Not yet used
} fields;
} grfPersistent;
@@ -291,12 +291,12 @@ void Msod::drawShape(
operands >> data.spid;
operands >> data.grfPersistent.info;
bytes -= 8;
- kdDebug(s_area) << "shape-id: " << data.spid << " type: " << funcTab[shapeType] << " (" << shapeType << ")" <<
+ kdDebug(s_area) << "tqshape-id: " << data.spid << " type: " << funcTab[tqshapeType] << " (" << tqshapeType << ")" <<
(data.grfPersistent.fields.fGroup ? " group" : "") <<
(data.grfPersistent.fields.fChild ? " child" : "") <<
(data.grfPersistent.fields.fPatriarch ? " patriarch" : "") <<
(data.grfPersistent.fields.fDeleted ? " deleted" : "") <<
- (data.grfPersistent.fields.fOleShape ? " oleshape" : "") <<
+ (data.grfPersistent.fields.fOleShape ? " oletqshape" : "") <<
(data.grfPersistent.fields.fHaveMaster ? " master" : "") <<
(data.grfPersistent.fields.fFlipH ? " flipv" : "") <<
(data.grfPersistent.fields.fConnector ? " connector" : "") <<
@@ -309,9 +309,9 @@ void Msod::drawShape(
if ((!m_isRequiredDrawing) && (m_requestedShapeId != data.spid))
return;
- // An active shape! Let's draw it...
+ // An active tqshape! Let's draw it...
- switch (shapeType)
+ switch (tqshapeType)
{
case 0:
if (m_opt->m_pVertices)
@@ -493,7 +493,7 @@ TQSize Msod::normaliseSize(
}
bool Msod::parse(
- unsigned shapeId,
+ unsigned tqshapeId,
const TQString &file,
const char *delayStream)
{
@@ -505,19 +505,19 @@ bool Msod::parse(
return false;
}
TQDataStream stream(&in);
- bool result = parse(shapeId, stream, in.size(), delayStream);
+ bool result = parse(tqshapeId, stream, in.size(), delayStream);
in.close();
return result;
}
bool Msod::parse(
- unsigned shapeId,
+ unsigned tqshapeId,
TQDataStream &stream,
unsigned size,
const char *delayStream)
{
stream.setByteOrder(TQDataStream::LittleEndian); // Great, I love TQt !
- m_requestedShapeId = shapeId;
+ m_requestedShapeId = tqshapeId;
m_isRequiredDrawing = false;
m_delayStream = delayStream;
@@ -854,8 +854,8 @@ void Msod::opDg(Header &, TQ_UINT32, TQDataStream &operands)
{
struct
{
- TQ_UINT32 csp; // The number of shapes in this drawing.
- TQ_UINT32 spidCur; // The last shape ID given to an SP in this DG.
+ TQ_UINT32 csp; // The number of tqshapes in this drawing.
+ TQ_UINT32 spidCur; // The last tqshape ID given to an SP in this DG.
} data;
operands >> data.csp >> data.spidCur;
@@ -878,10 +878,10 @@ void Msod::opDgg(Header &, TQ_UINT32, TQDataStream &operands)
{
struct
{
- TQ_UINT32 spidMax; // The current maximum shape ID.
+ TQ_UINT32 spidMax; // The current maximum tqshape ID.
TQ_UINT32 cidcl; // The number of ID clusters (FIDCLs).
- TQ_UINT32 cspSaved; // The total number of shapes saved.
- // (including deleted shapes, if undo
+ TQ_UINT32 cspSaved; // The total number of tqshapes saved.
+ // (including deleted tqshapes, if undo
// information was saved).
TQ_UINT32 cdgSaved; // The total number of drawings saved.
} data;
@@ -896,7 +896,7 @@ void Msod::opDgg(Header &, TQ_UINT32, TQDataStream &operands)
unsigned i;
operands >> data.spidMax >> data.cidcl >> data.cspSaved >> data.cdgSaved;
- kdDebug(s_area) << data.cspSaved << " shapes in " <<
+ kdDebug(s_area) << data.cspSaved << " tqshapes in " <<
data.cidcl - 1 << " clusters in " <<
data.cdgSaved << " drawings" << endl;
for (i = 0; i < data.cidcl - 1; i++)
@@ -943,31 +943,31 @@ void Msod::opSolvercontainer(Header &, TQ_UINT32 bytes, TQDataStream &operands)
void Msod::opSp(Header &op, TQ_UINT32 bytes, TQDataStream &operands)
{
// We want to defer the act of drawing a shape until we have seen any options
// that may affect it. Thus, we merely store the data away, and let opSpContainer
// do all the ahrd work.
- m_shape.type = op.opcode.fields.inst;
- m_shape.length = bytes;
- m_shape.data = new char [bytes];
- operands.readRawBytes(m_shape.data, bytes);
+ m_tqshape.type = op.opcode.fields.inst;
+ m_tqshape.length = bytes;
+ m_tqshape.data = new char [bytes];
+ operands.readRawBytes(m_tqshape.data, bytes);
}
void Msod::opSpcontainer(Header &, TQ_UINT32 bytes, TQDataStream &operands)
{
walk(bytes, operands);
// Having gathered all the information for this shape, we can now draw it.
TQByteArray a;
- a.setRawData(m_shape.data, m_shape.length);
+ a.setRawData(m_tqshape.data, m_tqshape.length);
TQDataStream s(a, IO_ReadOnly);
s.setByteOrder(TQDataStream::LittleEndian); // Great, I love TQt !
- drawShape(m_shape.type, m_shape.length, s);
- a.resetRawData(m_shape.data, m_shape.length);
- delete [] m_shape.data;
- m_shape.data = 0L;
+ drawShape(m_tqshape.type, m_tqshape.length, s);
+ a.resetRawData(m_tqshape.data, m_tqshape.length);
+ delete [] m_tqshape.data;
+ m_tqshape.data = 0L;
}
void Msod::opSpgr(Header &, TQ_UINT32, TQDataStream &operands)
@@ -1097,7 +1097,7 @@ void Msod::Options::initialise()
m_geoTop = 0;
m_geoRight = 21600;
m_geoBottom = 21600;
- m_shapePath = 1;
+ m_tqshapePath = 1;
delete m_pVertices;
m_pVertices = 0L;
m_fShadowOK = true;
@@ -1233,7 +1233,7 @@ void Msod::Options::walk(TQ_UINT32 bytes, TQDataStream &operands)
m_geoBottom = op.value;
break;
case 324:
- m_shapePath = op.value;
+ m_tqshapePath = op.value;
break;
case 383:
m_fShadowOK = (op.value & 0x0020) != 0;
@@ -943,31 +943,31 @@ void Msod::opSolvercontainer(Header &, TQ_UINT32 bytes, TQDataStream &operands)
void Msod::opSp(Header &op, TQ_UINT32 bytes, TQDataStream &operands)
{
- // We want to defer the act of drawing a shape until we have seen any options
+ // We want to defer the act of drawing a tqshape until we have seen any options
// that may affect it. Thus, we merely store the data away, and let opSpContainer
// do all the ahrd work.
@@ -943,31 +943,31 @@ void Msod::opSolvercontainer(Header &, TQ_UINT32 bytes, TQDataStream &operands)
{
walk(bytes, operands);
- // Having gathered all the information for this shape, we can now draw it.
+ // Having gathered all the information for this tqshape, we can now draw it.
TQByteArray a;
diff --git a/filters/karbon/msod/msod.h b/filters/karbon/msod/msod.h
index 3db6fc2f..f53146bf 100644
--- a/filters/karbon/msod/msod.h
+++ b/filters/karbon/msod/msod.h
@@ -44,15 +44,15 @@ public:
unsigned dpi);
virtual ~Msod();
// Called to parse the given file. We extract a drawing by shapeId.
// If the drawing is not found, the return value will be false.
bool parse(
- unsigned shapeId,
+ unsigned tqshapeId,
const TQString &file,
const char *delayStream = 0L);
bool parse(
- unsigned shapeId,
+ unsigned tqshapeId,
TQDataStream &stream,
unsigned size,
const char *delayStream = 0L);
@@ -114,14 +114,14 @@ private:
unsigned type;
char *data;
unsigned length;
- } m_shape;
+ } m_tqshape;
TQPoint normalisePoint(
TQDataStream &operands);
TQSize normaliseSize(
TQDataStream &operands);
void drawShape(
- unsigned shapeType,
+ unsigned tqshapeType,
TQ_UINT32 bytes,
TQDataStream &operands);
@@ -244,7 +244,7 @@ private:
TQ_UINT32 m_geoTop;
TQ_UINT32 m_geoRight;
TQ_UINT32 m_geoBottom;
- TQ_UINT32 m_shapePath;
+ TQ_UINT32 m_tqshapePath;
TQPointArray *m_pVertices;
bool m_fShadowOK;
bool m_f3DOK;
@@ -44,15 +44,15 @@ public:
unsigned dpi);
virtual ~Msod();
- // Called to parse the given file. We extract a drawing by shapeId.
+ // Called to parse the given file. We extract a drawing by tqshapeId.
// If the drawing is not found, the return value will be false.
bool parse(
diff --git a/filters/karbon/msod/msodimport.cc b/filters/karbon/msod/msodimport.cc
index e25889c0..903d50a2 100644
--- a/filters/karbon/msod/msodimport.cc
+++ b/filters/karbon/msod/msodimport.cc
@@ -46,18 +46,18 @@ MSODImport::~MSODImport()
{
}
-KoFilter::ConversionStatus MSODImport::convert( const TQCString& from, const TQCString& to )
+KoFilter::ConversiontqStatus MSODImport::convert( const TQCString& from, const TQCString& to )
{
if (to != "application/x-karbon" || from != "image/x-msod")
return KoFilter::NotImplemented;
- // Get configuration data: the shape id, and any delay stream that we were given.
- unsigned shapeId;
- emit commSignalShapeID( shapeId );
+ // Get configuration data: the tqshape id, and any delay stream that we were given.
+ unsigned tqshapeId;
+ emit commSignalShapeID( tqshapeId );
const char *delayStream = 0L;
emit commSignalDelayStream( delayStream );
kdDebug( s_area ) << "##################################################################" << endl;
- kdDebug( s_area ) << "shape id: " << shapeId << endl;
+ kdDebug( s_area ) << "tqshape id: " << tqshapeId << endl;
kdDebug( s_area ) << "delay stream: " << delayStream << endl;
kdDebug( s_area ) << "##################################################################" << endl;
/*
@@ -68,9 +68,9 @@ KoFilter::ConversionStatus MSODImport::convert( const TQCString& from, const TQC
kdDebug(s_area) << "MSODImport::filter: config: " << config << endl;
for (i = 0; i < args.count(); i++)
{
- if (args[i].startsWith("shape-id="))
+ if (args[i].startsWith("tqshape-id="))
{
- shapeId = args[i].mid(9).toUInt();
+ tqshapeId = args[i].mid(9).toUInt();
}
else
if (args[i].startsWith("delay-stream="))
@@ -91,7 +91,7 @@ KoFilter::ConversionStatus MSODImport::convert( const TQCString& from, const TQC
m_text += "<DOC mime=\"application/x-karbon\" syntaxVersion=\"0.1\" editor=\"WMF import filter\">\n";
m_text += " <LAYER name=\"Layer\" visible=\"1\">\n";
- if (!parse(shapeId, m_chain->inputFile(), delayStream))
+ if (!parse(tqshapeId, m_chain->inputFile(), delayStream))
return KoFilter::WrongFormat;
// close doc
@@ -175,7 +175,7 @@ void MSODImport::gotPicture(
kdWarning( s_area ) << "Couldn't determine the mimetype from the extension" << endl;
TQCString destMime; // intentionally empty, the filter manager will do the rest
- KoFilter::ConversionStatus status;
+ KoFilter::ConversiontqStatus status;
partRef = embedPart( srcMime.latin1(), destMime, status, TQString::number( key ) );
m_embeddeeData = 0;